==> call-uikit-vue2-2.4.0.tgz: package/src/TUICallService/locales/ja_JP.ts <==
export const ja_JP = {
  'hangup': '通話終了',
  'reject': '拒否',
  'other side reject call': '通話が拒否されました',
  'reject call': '通話拒否',
  'accept': '応答',
  'cancel': '通話をキャンセル',
  'other side line busy': '相手が通話中です',
  'in busy': '通話中',
  'call timeout': '呼び出しタイムアウト',
  'end call': '通話終了',
  'timeout': 'タイムアウト',
  'kick out': 'キックアウトされました',
  'caller calling message': '相手が招待を承諾するのを待っています。',
  'callee calling video message': 'ビデオ通話に招待されました。',
  'callee calling audio message': '音声通話に招待されました。',
  'no microphone access': 'マイクにアクセスできません',
  'no camera access': 'カメラにアクセスできません',
  'speaker': 'スピーカー',
  'Invited group call': 'グループ通話に招待されました。',
  'Those involved': '参加者：',
  'call': '通話',
  'video-call': 'ビデオ通話',
  'audio-call': '音声通話',
  'search': '検索',
  'search-result': '検索結果',
  'Wechat scan right QR code': 'WeChatで右側にあるQRコードを読み取ります。',
  'Use-phone-and-computer': '携帯電話とコンピュータを使用してビデオ通話を体験してください',
  'Scan the QR code above': '上のQRコードを読み取ります。',
  'no-user': 'ユーザーが見つかりませんでした',
  'member-not-added': 'メンバーが追加されていません',
  'not-login': 'ログインしていません',
  'login-status-expire': 'ログインの有効期限が過ぎています。ページを更新してもう一度お試しください',
  'experience-multi-call': '複数人で同時に音声通話できるグループ通話機能を体験するには、全機能のデモをダウンロードしてください',
  'not-support-multi-call': 'グループ通話インターフェイスが開いていません',
  'input-phone-userID': '携帯電話番号/ユーザーIDを入力してください',
  'userID': 'ユーザーID',
  'already-enter': 'すでに通話に参加しています',
  'waiting': '応答を待っています...',
  'camera-opened': 'カメラがオンになっています',
  'camera-closed': 'カメラがオフになっています',
  'microphone-opened': 'マイクがオンになっています',
  'microphone-closed': 'マイクがオフになっています',
  'camera': 'カメラ',
  'microphone': 'マイク',
  'image-resolution': '解像度',
  'default-image-resolution': 'デフォルト解像度',
  'invited-person': 'メンバーを招待',
  'video-to-audio': '音声通話に切り替えます',
  'me': '（自分）',
  'be-rejected': '通話が拒否されました, ',
  'be-no-response': '応答なし, ',
  'be-line-busy': '相手が通話中です, ',
  'be-canceled': '相手が通話をキャンセルしました',
  'voice-call-end': '音声通話が終了しました',
  'video-call-end': 'ビデオ通話が終了しました',
  'method-call-failed': '操作の同期に失敗しました',
  'failed-to-obtain-permission': '権限の取得に失敗しました',
  'environment-detection-failed': '環境の検出に失敗しました',
  'switchToAudioCall-call-failed': '音声通話に切り替えることはできません',
  'switchToVideoCall-call-failed': 'ビデオ通話に切り替えることはできません',
  'microphone-unavailable': '使用できるマイクがありません',
  'camera-unavailable': '使用できるカメラがありません',
  'ban-device': 'デバイスへのアクセスが拒否されました',
  'not-supported-webrtc': '現在の環境はWebRTCをサポートしていません',
  'blacklist-user-tips': 'ユーザーはブラックリストに登録され、通話が開始できませんでした',
  'is-already-calling': 'TUICallKit はすでに通話中です',
  'need-init': 'TUICallKitで通話を開始する前に、TUICallKitServer.init() メソッドが正常に実行されたことを確認してください。',
  "can't call yourself": '自分に電話をかけることができません',
  'accept-error': '接続できませんでした',
  'accept-device-error': '接続できませんでした。発信側デバイスを認証できません',
  'call-error': '通話が開始できませんでした',
  'browser-authorization': 'ブラウザ認証',
  'mac-privacy': 'システム環境設定 -> セキュリティとプライバシー ->プライバシー',
  'win-privacy': '設定 -> セキュリティとプライバシー ->アプリのアクセス許可',
  'mac-preferences': 'システム環境設定を開く',
  'win-preferences': 'システム設定を開く',
};

==> call-uikit-vue-2.4.8.tgz: package/src/TUICallService/locales/ja_JP.ts <==
export const ja_JP = {
  // 按钮文案 
  'hangup': '通話終了',
  'reject': '拒否',
  'accept': '応答',
  'camera': 'カメラ',
  'microphone': 'マイク',
  'speaker': 'スピーカー',
  // 通话结果
  'other side reject call': '通話が拒否されました',
  'reject call': '通話拒否',
  'cancel': '通話をキャンセル',
  'other side line busy': '相手が通話中です',
  'in busy': '通話中',
  'call timeout': '呼び出しタイムアウト',
  'end call': '通話終了',
  // 通话提示语
  'caller calling message': '応答を待っています',
  'callee calling video message': 'ビデオ通話に招待されました',
  'callee calling audio message': '音声通話に招待されました',
  'no microphone access': 'マイクにアクセスできません',
  'no camera access': 'カメラにアクセスできません',
  'invite member': 'メンバーを招待する',
  // 弹出层文案
  'browser-authorization': 'ブラウザ認証',
  'mac-privacy': 'システム環境設定 -> セキュリティとプライバシー ->プライバシー',
  'win-privacy': '設定 -> セキュリティとプライバシー ->アプリのアクセス許可',
  'mac-preferences': 'システム環境設定を開く',
  'win-preferences': 'システム設定を開く',
  'Please enter userID': 'ユーザーIDを入力してください',
  'View more': 'もっと見る',
  'people selected': '人が選択されました',
  'Select all': 'すべて選択',
  'Cancel': 'キャンセル',
  'Done': '完了',
  // UI3.0文案
  'open camera': 'オープンカメラ',
  'close camera': 'カメラを閉じる',
  'open microphone': 'オープンマイク',
  'close microphone': 'マイクを閉じる',  
  'camera enabled': 'カメラオン',
  'camera disabled': 'カメラオフ',
  'microphone enabled': 'マイクオン',
  'microphone disabled': 'マイクオフ',
  'speaker phone': 'スピーカーオン',
  'wait to be called': '待機中',
  'answered': '接続済み',
  'people in the call': '通話に参加している人たち',
  'failed to obtain speakers': 'スピーカーが見つかりません',
  // 待废弃文案
  'timeout': 'タイムアウト',
  'kick out': 'キックアウトされました',
  'Invited group call': 'グループ通話に招待されました。',
  'Those involved': '参加者：',
  'call': '通話',
  'video-call': 'ビデオ通話',
  'audio-call': '音声通話',
  'search': '検索',
  'search-result': '検索結果',
  'Wechat scan right QR code': 'WeChatで右側にあるQRコードを読み取ります。',
  'Use-phone-and-computer': '携帯電話とコンピュータを使用してビデオ通話を体験してください',
  'Scan the QR code above': '上のQRコードを読み取ります。',
  'no-user': 'ユーザーが見つかりませんでした',
  'member-not-added': 'メンバーが追加されていません',
  'not-login': 'ログインしていません',
  'login-status-expire': 'ログインの有効期限が過ぎています。ページを更新してもう一度お試しください',
  'experience-multi-call': '複数人で同時に音声通話できるグループ通話機能を体験するには、全機能のデモをダウンロードしてください',
  'not-support-multi-call': 'グループ通話インターフェイスが開いていません',
  'input-phone-userID': '携帯電話番号/ユーザーIDを入力してください',
  'userID': 'ユーザーID',
  'already-enter': 'すでに通話に参加しています',
  'waiting': '応答を待っています...',
  'camera-opened': 'カメラがオンになっています',
  'camera-closed': 'カメラがオフになっています',
  'microphone-opened': 'マイクがオンになっています',
  'microphone-closed': 'マイクがオフになっています',
  'image-resolution': '解像度',
  'default-image-resolution': 'デフォルト解像度',
  'invited-person': 'メンバーを招待',
  'video-to-audio': '音声通話に切り替えます',
  'me': '(自分)',
  'be-rejected': '通話が拒否されました, ',
  'be-no-response': '応答なし, ',
  'be-line-busy': '相手が通話中です, ',
  'be-canceled': '相手が通話をキャンセルしました',
  'voice-call-end': '音声通話が終了しました',
  'video-call-end': 'ビデオ通話が終了しました',
  'method-call-failed': '操作の同期に失敗しました',
  'failed-to-obtain-permission': '権限の取得に失敗しました',
  'environment-detection-failed': '環境の検出に失敗しました',
  'switchToAudioCall-call-failed': '音声通話に切り替えることはできません',
  'switchToVideoCall-call-failed': 'ビデオ通話に切り替えることはできません',
  'microphone-unavailable': '使用できるマイクがありません',
  'camera-unavailable': '使用できるカメラがありません',
  'ban-device': 'デバイスへのアクセスが拒否されました',
  'not-supported-webrtc': '現在の環境はWebRTCをサポートしていません',
  'blacklist-user-tips': 'ユーザーはブラックリストに登録され、通話が開始できませんでした',
  'is-already-calling': 'TUICallKit はすでに通話中です',
  'need-init': 'TUICallKitで通話を開始する前に、TUICallKitServer.init() メソッドが正常に実行されたことを確認してください。',
  "can't call yourself": '自分に電話をかけることができません',
  'accept-error': '接続できませんでした',
  'accept-device-error': '接続できませんでした。発信側デバイスを認証できません',
  'call-error': '通話が開始できませんでした',
};
